;;These are global variables and lists that are available to individual agents, patches, and the observer
globals [
totalDiversityList             ;;list of cultvariants in the archaeological landscape
totalFrequencyList             ;;list of the frequency of different cultvariants in the archaeological landscape
numberUnique                   ;;richness of cultvariants in the archaeological landscape
numberExtinctionEvents         ;;running tally of the number of local extinctions
numberCopyErrors               ;;running tally of the number of copy errors
nextUniqueVariant              ;;the integer that will be assigned as a result of the next copy error under the infinite variant model of copy error
mostPrevalentVariant           ;;the most prevalent cultural variant in the entire time-transgressive archaeological landscape
]

;;These are patch variables and lists
patches-own [
patchDiversityList                 ;;list of cultvariants in the patch's assemblage
patchFrequencyList                 ;;list of the frequency of different cultvariants in the patch's assemblage
relativeFreqMostPrevalentVariant   ;;relative frequency of the mostPrevalentVariant in the patch's assemblage
]

;;These are variables of individuals
turtles-own [
  age                 ;; 0=naive generation, 1=experienced generation
  cultvariant         ;; discrete variant (integer) of a selectively neutral culturally transmitted trait
  ]



;;to initialize the simulation before a run
to setup
  ;;clear all previous variables and plots from a previous run
  ca

  ;;set the random number seed to the global variable "seed"
  random-seed seed

  ;;create a group of N individuals in each patch
  ask patches
  [
  sprout N  [initIndividual]  ;;and initialize their state variables
  ]

;;create empty lists for assemblage diversity and frequency at the scale of the landscape...
set totalDiversityList (list)
set totalFrequencyList (list)
ask patches [  ;;...and at the scale of each patch
  set patchDiversityList (list)
  set patchFrequencyList (list)
  set relativeFreqMostPrevalentVariant 0
]

;;set global "counters" to 0
set numberExtinctionEvents 0
set numberCopyErrors 0

set mostPrevalentVariant -9999   ;;this should not be set to 0 at the start

;;set nextUniqueVariant for use under the infinite alleles model of copy error
ifelse initPopulation = "heterogeneous"  ;;if we are starting with a heterogeneous population in which everyone starts with a unique cultvariant
  [
  set nextUniqueVariant max [who] of turtles + 1   ;;then the next unique value is the integer one greater than the max who value
  ]
  [  ;;else, we are starting with a homogeneous population in which everyone starts with a cultvariant = 0
  set nextUniqueVariant 1   ;;the nextUniqueVariant should equal 1 when all individuals start with 0
  ]

  ;;reset time to zero
  reset-ticks

end



;;to set the cultvariant and color of initial agents
to initIndividual

  set size 1

  ifelse initPopulation = "heterogeneous"  ;;if we begin with a heterogeneous population
  [
    set cultvariant who    ;;all agents start with a unique cultvariant equal to their "who" value
    set color cultvariant
  ]
  [ ;;else, we begin with a homogeneous population
    set cultvariant 0  ;;all agents start with cultvariant = 0
    set color blue
  ]

end



to go
  ;;each time step consists of 7-8 phases and data update/plot
  ;;the order of the phases is important and should not be altered

  ;;A new time step begins, increment "ticks"
  tick

  ;;Phase 1: Intergroup cultural transmission
  if intergroupCTRate > 0 [intergroup-cultural-transmission]

  ;;Phase 2: All groups are exposed to local extinction
  ask patches [local-extinction]

  ;;Phase 3: Empty patches are recolonized by a neighboring group
  ask patches with [count turtles-here = 0] [recolonize]

  ;;Phase 4: Agents age
  ask turtles [set age 1]  ;;All surviving turtles age to 1, designating them as members of the "parental" generation

  ;;Phase 5: The naive generation is created in one of two ways depending on the cultural transmission mechanism
  ifelse cultTrans = "unbiased" or cultTrans = "conformist"  ;;If cultural transmission is unbiased or conformist biased
  [
  ask patches [create-generation]  ;Each patch creates N members of the new ("naive") generation and cultural transmission comes later
  ]
  [;;else, it is vertical cultural transmission, so cultVariant is passed from parent to offspring during creation of the new generation
   ask patches [create-vertical-generation]
  ]

  ;;Phase 6: Cultural transmission and then copy error
  ask turtles with [age = 0] [intragroup-cultural-transmission]  ;;note that this includes only individuals in the naive generation
  ask turtles with [age = 0] [copy-error]  ;;next, a chance at copy error for all forms of cultural transmission

  ;;Phase 7: Cull the experienced generation
  ask turtles with [age = 1] [die]


  ;;Data update / plot: Calculate number of unique variants in the population and plot richness by ticks
  let uniqueList (list)  ;;empty the local list each time step
  ask turtles
  [
  set uniqueList lput cultvariant uniqueList
  ]
  set uniqueList remove-duplicates uniqueList
  set numberUnique length uniqueList
  ;;Plot richness of cultvariant in the population over time
  plot numberUnique



  ;;Phase 8: Cultural variant deposition starts at tick 10,001
  if ticks > 10000
  [
  ask turtles [
    create-total-assemblage     ;;each turtle adds its variant to the total assemblage
    create-patch-assemblage     ;;each turtle adds its variant to the assemblage in its patch
    ]

  ;;Data collection
  ;;Starting at 10001 ticks, collect assemblage data at intervals of d=1, 10, 100, 1000, and 10000
  if ticks = 10001 or ticks = 10010 or ticks = 10100 or ticks = 11000 or ticks = 20000
  [

   ;;;;;First, indentify mostPrevalentVariant in the archaeological landscape
   ;;show "totalFrequencyList"
   ;;show totalFrequencyList  ;;for teesting
   let mostFrequent max totalFrequencyList
   ;;show "mostFrequent"
   ;;show mostFrequent  ;;for testing
   ;;show "totalDiversityList"
   ;;show totalDiversityList  ;;for testing
   set mostPrevalentVariant item (position mostFrequent totalFrequencyList) totalDiversityList
   ;;show "mostPrevalentVariant"  ;;for testing
   ;;show mostPrevalentVariant  ;;for testing

   ask patches
   [
     calculate-relative-freq  ;;cacluate the relative frequency of mostPrevalentVariant
   ]

   if collectMoransData = true
    [
    collect-morans-datafile  ;;write the data to file
    ]
  ]

  ;;Stop condition
  if ticks = 20000   ;;The simulation ends after 20000 ticks
  [
  export-plot "Richness" (word "richness" behaviorspace-experiment-name behaviorspace-run-number ".txt")  ;;exports the richness plot for later analysis
  stop  ;;stops the entire simulation
  ]

  ]


end ;;end of "go"




to intergroup-cultural-transmission
  ;;observer method
  ;;note that intergroup cultural transmission is horizontal (among experienced agents only) and it is not susceptible to copy error

  ask n-of round (count turtles * (intergroupCTRate / 2)) turtles
   [
      if intergroupCTExtent = "global"        ;;geographic extent of intergroup cultural transmission is global
      [
      let myVariant cultvariant               ;;myVariant is a local variable
      let partner one-of turtles-on one-of other patches

      set cultvariant [cultvariant] of partner    ;;swap with a partner chosen randomly from any of the other groups
      ask partner [set cultvariant myVariant]
      ]

      if intergroupCTExtent = "local"         ;;geographic extent of intergroup cultural transmission is local
      [
      let myVariant cultvariant               ;;myVariant is a local variable
      let partner one-of turtles-on one-of neighbors

      set cultvariant [cultvariant] of partner    ;;swap with a partner chosen randomly from one of the Moore neighbor groups
      ask partner [set cultvariant myVariant]
      ]
    ]

end



to local-extinction
  ;;patch method
  ;;if a random number drawn from a uniform distribution bounded by 0 and 1 is less than extinctionprob,
  ;;the group goes "extinct" and all agents occupying the patch die

  if random-float 1 < extinctionProb
  [
    set numberExtinctionEvents numberExtinctionEvents + 1
    ask turtles-here [die]
  ]

end


to recolonize
  ;;patch method
  ;;a group chosen randomly from ego's Moore neighborhood sends half, rounded up, of its experienced agents (age=1) to ego
  if count turtles-here = 0 ;;If a patch contains no turtles as the result of an extinction event
  [

    let emptypatch self

    ifelse not any? neighbors with [count turtles-here > 1] ;;An error will occur if there are no Moore neighbors available to recolonize the empty cell
    [
     show "None of the surrounding cells have foragers."
     show ticks
     show seed
     error "All neighbors were empty."   ;;custom run-time error

    ]
    [
    ask one-of neighbors with [count turtles-here > 1] ;;The empty cell asks a randomly-chosen Moore neighbor to recolonize it
      [
        ask n-of round (count turtles-here / 2) turtles-here ;;Half of the current members of the selected patch will move to the empty cell
        [
        move-to emptypatch
        ]
      ]
    ]
  ]

end



to create-generation
  ;;patch method used when cultTrans = unbiased or conformist
  ;;The new generation is composed of individuals who will undergo intragroup cultural transmission

  sprout N ;;the naive generation is composed of N individuals in each patch
   [
    set age 0           ;;set the age of the newbie to 0.
    set cultvariant 0   ;;agent sets cultvariant to 0 for now, but this will change during intragroup cultural transmission (see culttransmission below)
    set color cultvariant
   ]

end


to create-vertical-generation
  ;;patch method for creating the new generation when cultTrans = vertical. In this case, the new generation is composed of individuals who inherit their parent's cultvariant.
  ;;each experienced agent in the patch creates at least one new agent (or offspring)
   while [count turtles-here with [age = 0] < N]
   [
     ifelse count turtles-here with [age = 1] <= (N - count turtles-here with [age = 0])
     [
       ask turtles-here with [age = 1]   ;;ask all of the experienced members of the group to produce one offspring and teach it
       [
         hatch 1
         [
         set age 0 ;;set the age of the newbie to 0.  The offspring inherits its parent's values at the other variables.
         ]
       ]
     ]
     [ ;;else there are more experienced members than offspring needed, so at least one experienced member of the group will teach exactly one more naive agent than the other experienced members in the group
      ask n-of (N - count turtles-here with [age = 0]) turtles-here with [age = 1]
      [
        hatch 1
        [
        set age 0  ;;set the age of the newbie to 0.  It inherits its parent's values at the other variables.
        ]
      ]
     ]
   ]

 end


to intragroup-cultural-transmission
  ;;turtle method
  ;;this is used to operationalize unbiased and conformist biased intragroup cultural transmission
  ;;note that agents do nothing during this phase if cultTrans = "vertical"


  if cultTrans = "conformist"   ;conformist cultural transmission: each naive agent learns the modal variant of the experienced generation in its group
  [
   set cultvariant one-of modes [cultvariant] of turtles-here with [age = 1]  ;;each learner copies the modal variant of the parental generation within its group. If there are two or more modal variants, then each learner selects one with equal probability.
   set color cultvariant
  ]

  if cultTrans = "unbiased"   ;unbiased oblique cultural transmission: each naive agent chooses a teacher at random from the experienced individuals within its group
  [
   set cultvariant [cultvariant] of one-of turtles-here with [age = 1]  ;;each learner copies a randomly selected experienced individual (with replacement) from the group
   set color cultvariant
  ]

end



to copy-error
  ;;turtle method, note that this should only be called for turtles with [age = 0]
  ;;all forms of intragroup cultural transmission are susceptible to copy error
  ;;if the random number drawn from a uniform distribution bounded by 0 and 1 is less than errorProb, then the variant ultimately adopted by the learner will be different from its target value
  if random-float 1 < errorProb
  [
   ;;if age = 1 [ show "I am in the parental generation and I am about to change my cultvariant due to copy error when I should not be."]  ;;for testing
  set numberCopyErrors numberCopyErrors + 1
  ;;show numberCopyErrors  ;;for testing

 if copyErrorModel = "bidirectSingleStepwise"     ;;bidirectional single stepwise model of copy error
   [
   ifelse random 2 = 1
    [set cultvariant cultvariant + 1]
    [set cultvariant cultvariant - 1]
   ]


  if copyErrorModel = "infiniteVariants"          ;;infinite variants model of copy error
    [
     set cultvariant nextUniqueVariant
     set nextUniqueVariant nextUniqueVariant + 1
    ]


  if copyErrorModel = "finiteVariants"            ;;finite variants model of copy error
  [
   let oldVariant cultvariant
   while [oldVariant = cultvariant]               ;;this while loop guards against the possibility that the new variant value is the same as the present one
    [
    set cultvariant random 100                    ;;an integer between 0 and 99 is chosen randomly
    ]
  ]

  ]

  set color cultvariant
end




;;Archaeological landscape assemblage formation
to create-total-assemblage
  ;;turtle method
  ;;starting with tick 10,001, every individual adds a copy of its variant to global lists of variants at the end of each tick

  let myVariant cultvariant  ;;myVariant is a local variable.

  ifelse member? myVariant totalDiversityList = false  ;;if one's cultural variant is NOT already on totalDiversityList
  [
    ;;write "cultVariant is NOT already on totalDiversityList."  ;;for testing
    ;;write "myVariant" show myVariant ;;for testing
    ;;write "totalDiversityList" show totalDiversityList ;;for testing

    ;;individual adds its variant to the end of the global diversity list (list of every unique variant)
    ;;write "Old totalDiversityList" show totalDiversityList ;;for testing
    set totalDiversityList lput myVariant totalDiversityList
    ;;write "New totalDiversityList" show totalDiversityList ;;for testing

    ;;individual adds a 1 to the end of global frequency list (list of the frequency of all variants)
    ;;write "Old totalFrequencyList" show totalFrequencyList ;;for testing
    set totalFrequencyList lput 1 totalFrequencyList
    ;;write "New totalFrequencyList" show totalFrequencyList ;;for testing
  ]
  [ ;;else one's cultural variant IS already on totalDiversityList

    ;;write "cultVariant IS already on totalDiversityList."  ;;for testing
    ;;write "myVariant" show myVariant ;;for testing
    ;;write "totalDiversityList" show totalDiversityList ;;for testing

    ;;add 1 to the previous frequency of its variant at the proper position on the list
    let oldFrequency item (position myVariant totalDiversityList) totalFrequencyList
    ;;write "Old totalFrequencyList" show totalFrequencyList ;;for testing
    set totalFrequencyList replace-item (position myVariant totalDiversityList) totalFrequencyList (oldFrequency + 1)
    ;;write "New totalFrequencyList" show totalFrequencyList ;;for testing
  ]


end




;;Locality assemblage formation
to create-patch-assemblage
  ;;turtle method
  ;;starting with tick 10,001, every individual adds a copy of its variant to its patch's lists of variants at the end of each tick

  let myVariant cultvariant   ;;myVariant is a local variable.


  ifelse member? myVariant patchDiversityList = false   ;;if myVariant is NOT already on patchDiversityList
  [
    ;;write "myVariant is NOT already in patchDiversityList."
    ;;write "myVariant" show myVariant ;;for testing
    ;;write "withinGroupDiversity" show patchDiversityList ;;for testing

    ;;individual adds its variant to the end of patchDiversityList
    ;;write "Old Group Diversity" show patchDiversityList ;;for testing
    set patchDiversityList lput myVariant patchDiversityList
    ;;write "New Group Diversity" show patchDiversityList ;;for testing
    ;;write "totalDiversity" show totalDiversityList ;;for testing         this should not show a change, because this is done in createtotalassemblage LSP  JAN 2018

    ;;individual adds 1 to the end of the group frequency list
    ;;write "Old Group Frequency" show patchFrequencyList ;;for testing
    set patchFrequencyList lput 1 patchFrequencyList
    ;;write "New Group Frequency" show patchFrequencyList ;;for testing
  ]
  [;;else, myVariant IS already in patchDiversityList

    ;;write "myVariant IS already in patchDiversityList."
    ;;write "myVariant" show myVariant ;;for testing
    ;;write "Group Diversity" show patchDiversityList ;;for testing

    ;;add 1 to the previous frequency of its variant at the proper position on the list
    let oldFrequency item (position myVariant patchDiversityList) patchFrequencyList
    ;;write "Old Group Frequency" show patchFrequencyList ;;for testing
    set patchFrequencyList replace-item (position myVariant patchDiversityList) patchFrequencyList (oldFrequency + 1)
    ;;write "New Group Frequency" show patchFrequencyList ;;for testing

  ]

end





to calculate-relative-freq
  ;;patches method
  ;;This method calculates the relative frequency of mostPrevalentVariant in the assemblage of each patch

  ;;show "mostPrevalentVariant"  ;;for testing
  ;;show mostPrevalentVariant ;;for testing

  ;;show "patchDiversityList"  ;;for testing
  ;;show patchDiversityList   ;;for testing


  ifelse member? mostPrevalentVariant patchDiversityList   ;;if the locality's assemblage contains at least one instance of the most prevalent variant
  [
   ;;show "patchFrequencyList"  ;;for testing
   ;;show patchFrequencyList   ;;for testing

   let freqMPV item (position mostPrevalentVariant patchDiversityList) patchFrequencyList   ;;this is the frequency of the mostPrevalentVariant in the locality's assemblage
   ;;show "freqMPV"  ;;for testing
   ;;show freqMPV   ;;for testing

   set relativeFreqMostPrevalentVariant (freqMPV / sum patchFrequencyList)  ;;set relativeFreqMostPrevalentVariant to the number of times the mostPrevalentVariant appears divided by the total number of variants dropped in the patch (The number of variants dropped in each patch should be equal to (N * (ticks - 10,0000)).)
   ;;show "relativeFreqMostPrevalentVariant"  ;;for testing
   ;;show relativeFreqMostPrevalentVariant   ;;for testing

  ]
  [  ;;else, the locality's assemblage does not contain the most prevalent variant
   set relativeFreqMostPrevalentVariant 0      ;;set relativeFreqMostPrevalentVariant to 0
   ;;show "relativeFreqMostPrevalentVariant"  ;;for testing
   ;;show relativeFreqMostPrevalentVariant   ;;for testing
  ]


end





to collect-morans-datafile
  ;;observer method
  ;;collects the data required to calculate Local Moran's I_i in R with the "spdep" package

  ifelse file-exists? "LocalMoransIData.csv" = true
  [
    file-open "LocalMoransIData.csv"
    ask patches
    [
    file-write behaviorspace-experiment-name file-write behaviorspace-run-number file-write seed file-write ticks file-write initPopulation file-write cultTrans file-write extinctionprob file-write errorprob file-write copyErrorModel file-write intergroupCTExtent file-write intergroupCTRate file-write pxcor file-write pycor file-write relativeFreqMostPrevalentVariant file-print ""
    ]
  file-close
  ]
  [
   file-open "LocalMoransIData.csv"
   file-write "Experiment" file-write "Run Number" file-write "seed" file-write "ticks" file-write "initPopulation" file-write "cultTrans" file-write "extinctionProb" file-write "errorProb" file-write "copyErrorModel" file-write "intergroupCTExtent" file-write "intergroupCTRate" file-write "pxcor" file-write "pycor" file-write "relativeFreqMostPrevalentVariant" file-print ""

  ask patches
    [
    file-write behaviorspace-experiment-name file-write behaviorspace-run-number file-write seed file-write ticks file-write initPopulation file-write cultTrans file-write extinctionprob file-write errorprob file-write copyErrorModel file-write intergroupCTExtent file-write intergroupCTRate file-write pxcor file-write pycor file-write relativeFreqMostPrevalentVariant file-print ""
    ]
  file-close
  ]


end
@#$#@#$#@
GRAPHICS-WINDOW
195
10
443
259
-1
-1
12.0
1
10
1
1
1
0
1
1
1
0
19
0
19
1
1
1
ticks
30.0

BUTTON
2
46
62
79
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
128
46
192
79
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
63
46
126
79
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
95
10
187
43
N
N
0
100
25.0
1
1
NIL
HORIZONTAL

SLIDER
4
211
116
244
errorProb
errorProb
0
.1
1.0E-4
.001
1
NIL
HORIZONTAL

SLIDER
3
129
141
162
extinctionProb
extinctionProb
0
.1
0.01
.001
1
NIL
HORIZONTAL

SLIDER
2
10
94
43
seed
seed
0
100
7.0
1
1
NIL
HORIZONTAL

PLOT
448
10
648
160
Richness
time
richness
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"number of variants" 1.0 0 -16777216 true "" ""

MONITOR
449
213
506
258
N
count turtles
0
1
11

CHOOSER
3
164
118
209
cultTrans
cultTrans
"unbiased" "conformist" "vertical"
2

CHOOSER
3
82
117
127
initPopulation
initPopulation
"homogeneous" "heterogeneous"
1

SWITCH
5
377
157
410
collectMoransData
collectMoransData
0
1
-1000

MONITOR
449
164
546
209
% copy errors
numberCopyErrors / (N * (max-pxcor + 1) * (max-pycor + 1) * ticks)
6
1
11

CHOOSER
4
246
153
291
copyErrorModel
copyErrorModel
"infiniteVariants" "bidirectSingleStepwise" "finiteVariants"
1

SLIDER
5
293
149
326
intergroupCTRate
intergroupCTRate
0
.2
0.0
.01
1
NIL
HORIZONTAL

CHOOSER
5
330
126
375
intergroupCTExtent
intergroupCTExtent
"local" "global"
1

TEXTBOX
197
278
604
369
Directions\n1. Set the global variables as desired.\n2. Hit \"setup\" to initialize the population.\n3. Hit \"go\" to start the simulation (the run will stop after 20,000 ticks).\n4. Hit \"go\" again to stop the simulation before 20,000 ticks.\n5. If collectMoransData = ON, then data are collected at time step 10,001, 10,010, 10,100, 11,000, and 20,000.
10
0.0
1

@#$#@#$#@
# Model Details
Version 1.0
March 2018
Programmed by Galen Miller-Atkins and Luke Premo
Compatible with NetLogo v. 6.0.2
The experiments reported in Miller-Atkins and Premo (2018) can be found in BehaviorSpace. 



# Model Description
This description of the model presented in Miller-Atkins and Premo (2018) follows the ODD protocol (Grimm et al. 2010).

## Purpose
We employ this spatially explicit agent-based model to begin to examine how time-averaging can affect the spatial scale of cultural similarity in archaeological assemblage data. The model was built to address this question: to what extent does time-averaging affect the scale of local spatial association in the relative frequency of the most prevalent cultural variant in an archaeological landscape?

## Entities, State Variables, and Scale
In the context of our research question, the agents in our model represent hominins, but here we refer to them more generally as individuals. Each individual displays two variables: age (either a 0 or a 1) and a neutral cultural variant, denoted cultvariant. If born on the current time step, the individual has an age of 0. If born the previous time step, the individual has an age of 1. Each individual displays a cultural variant, represented by an integer. In this model, cultural variants are selectively neutral in the sense that they do not confer fitness benefits upon the individual. Individuals have three actions: learn, deposit a cultural variant, and die. Naïve individuals (age=0) learn a variant from the experienced generation (age=1). Naive individuals learn socially through one of three cultural transmission mechanisms: unbiased, vertical, or conformist. Experienced individuals can engage in horizontal intergroup cultural transmission.

There are 10 global variables: _N_, initPopulation, extinctionProb, errorProb, copyErrorModel, cultTrans, intergroupCTRate, intergroupCTExtent, _d_, and seed. _N_ is the maximum number of individuals per group. When initPopulation = heterogeneous, are initialized with unique cultvariant values. By contrast, when initPopulation = homogeneous, then every individual is initialized with a cultvariant of 0. extinctionProb represents the probability per group per time step of local extinction. Each extinction event is followed by a recolonization event. errorProb is the probability per intragroup transmission event that the naïve agent makes an error when copying the target value of its cultural variant. copyErrorModel designates which of three copy error models are employed through the simulation run. According to a bidirectional single-stepwise model of copy error, the naïve individual mistakenly adopts an integer that is one greater or one less than the target value with equal probability. For example, a naïve individual who makes an error while attempting to copy the variant “5” will ultimately adopt either “4” or “6” with equal probability. Note that the bidirectional single-stepwise model of copy error allows for “back-innovations,” such that an error results in the same variant displayed prior to the previous copy error. In fact, under the bidirectional single-stepwise model, an error results in a “back-innovation” with probability .5. We also investigate the effects of time-averaging under a finite variants model of copy error in which the number of possible variants is arbitrarily capped at 100. In this case, each copy error results in the naive individual being randomly assigned one of the 99 variants that is not its intended target value. The probability of a “back-innovation” (per copy error) in the finite variants model is 1/99. The infinite variants model of copy error eliminates the possibility of back-innovation altogether. With infinite variants, each copying error results in the introduction of a novel cultural variant never before seen during the course of the simulation run. cultTrans designates the mechanism of intragroup cultural transmission employed throughout the simulation run. Under unbiased transmission, each naïve individual randomly selects (with replacement) an experienced member of its group to serve as its teacher. Vertical cultural transmission is modeled in the same way as the genetic transmission of haploid genes during asexual reproduction—each naïve individual inherits its parent’s cultural variant. Under conformist biased cultural transmission, naïve individuals attempt to copy the modal cultural variant of the experienced members of their group. If the majority of a group’s experienced members display “5,” then every member of the naïve generation in that group will attempt to copy “5.” In the event that a group’s experienced generation exhibits more than one mode, each naïve individual in that group chooses from among the modal variants with equal probability. For instance, assuming “5” and “8” are both modes of a group’s experienced generation, some naïve members of that group may try to copy “5” while others in the same group try to copy “8.” intergroupCTRate represents the proportion of the population that engages in intergroup cultural transmission. intergroupCTExtent defines the spatial extent over which horizontal intergroup cultural transmission takes place. When intergroupCTExtent=local, each agent chosen to form a pair randomly chooses its intergroup transmission “partner” from among the members of one of the eight groups immediately adjacent to its group. When intergroupCTExtent=global, each agent chosen to form a pair randomly chooses its partner from a group other than its own without respect to the other group’s location on the lattice. _d_ represents the duration of assemblage formation. Increasing _d_ increases the degree to which an assemblage is time-averaged. seed is the integer value used to seed random number generator at the start of the simulation.

Time is represented with discrete steps, or “ticks” in the parlance of NetLogo. In this model, each tick encompasses the time required for both intergroup cultural transmission among members of the experienced generation and intragroup transmission of cultural variants from the experienced generation to the naive generation. The model is spatially explicit. The “world” consists of a 20 x 20 grid, wrapped around a torus to avoid edge effects. Each square grid cell, called a patch in NetLogo, can be occupied by up to _N_ individuals. Each patch also contains an archaeological assemblage that forms as inhabitants deposit cultural variants through simulated time. Following terminology used in distributional archaeology (Ebert 1992), we refer to the entire set of 400 assemblages collectively as the archaeological landscape.

## Process Overview and Scheduling
Seven processes take place every time step in the following order: intergroup cultural transmission, local extinction, recolonization, agents age, a new generation is born, intragroup cultural transmission, and then the experienced generation is culled. Once the simulation has reached 10,001 ticks an eighth process, cultural variant deposition, occurs after the experienced generation is culled.

### 1. Intergroup Cultural Transmission
A proportion (intergroupCTRate/2) of agents are randomly chosen and asked to find a partner outside of their own group.  When intergroup transmission is "local," the partner must come from a neighboring group.  When intergroup transmission is "global," the partner can be a member of group other than ego's. Once a partner is chosen, the pair of individuals simply swap their cultural variants with each other across group boundaries.
 
### 2. Local Extinction
Each patch draws a number from a uniform distribution between 0 and 1. If that number is less than or equal to extinctionProb, then all agents occupying that patch die.

### 3. Local Recolonization
Each patch with zero members randomly selects a patch from among those in its Moore neighborhood that have at least 2 members. The randomly chosen neighbor then sends half of its members (rounded up to the nearest whole number) to the empty cell to serve as the recolonizers.

### 4. Aging
All agents set their age to 1, establishing the “experienced” generation that will teach members of the naive generation. Only “experienced” agents may serve as teachers.

### 5. Create Naive Generation
Each group creates N naive individuals that have age = 0. In the presence of conformist biased cultural transmission or unbiased cultural transmission, N naïve individuals are created in each patch without reference to any biological parents in the experienced generation.  Because cultural transmission is oblique in both cases, there is no need to track biological lineages. By contrast, in the presence of vertical cultural transmission each member of the experienced, or “parental,” generation in each patch reproduces (asexually) iteratively until N naive individuals have been created.

### 6. Intragroup Cultural Transmission
Cultural transmission occurs via one of three mechanisms: conformist, unbiased, or vertical cultural transmission. Note that naïve agents cannot learn from members of neighboring groups under any condition. Intragroup cultural transmission is imperfect and naive individuals can make mistakes during transmission. Thus, each naive agent commits a copying error with probability errorProb per transmission event.

### 7. Cull Experienced Generation
All individuals in the “experienced” generation (i.e., age=1) die.

### 8. Deposit Cultural Variant
Starting with time step 10,001, at the end of each time step every agent contributes its cultvariant to the archaeological assemblage of its cell.

## Design Concepts
### Learning
Individuals are social learners. Naïve agents learn from the experienced generation. Naive individuals adopt cultural variants through one of three cultural transmission mechanisms: conformist, unbiased, or vertical cultural transmission. Experienced individuals can also learn horizontally via intergroup cultural transmission.

### Sensing
Naïve individuals have access to the age and cultvariant of the experienced individuals that occupy their patch.

### Interaction
Agents interact with each other only during cultural transmission. Interactions between agents of different ages are restricted to members of the same group.  Naïve individuals do not interact with each other.  Experienced individuals interact with each other only during intergroup cultural transmission.

### Stochasticity
Stochasticity figures heavily in this model--here are just a few examples: Copying error and local extinctions are both probabilistic. In unbiased cultural transmission, teachers are chosen randomly (and with replacement) from among the experienced group members. In conformist biased transmission, ties between multiple modes of cultural variants are broken randomly. During recolonization, the colonizing group is chosen randomly from among the empty cell’s Moore neighbors that contain at least 2 members and recolonizers are chosen randomly from the selected group. Please see the source code for the many other examples of stochasticity in this model.

### Collectives
There are two kinds of collectives in this model: groups and generations. The population is spatially structured by groups. Each unique cell on the 20x20 grid can host one group of _N_ individuals. Cultural transmission takes place within groups. Only the members of the group that currently occupies a cell can contribute cultural variants to that cell’s assemblage during the current time step. A local extinction event eliminates all individuals within the affected group. Individuals are also classified by age into two distinct generations. Naive individuals are marked by an age of 0. Members of the experienced generation are marked by an age of 1.


## Details
### Initialization
Each simulation starts with 400 groups of _N_ individuals. Population size is held constant throughout the simulation. The parameter values used in our experimental design are shown in Table 1. Twenty unique simulations were run for each parameter combination reported. Please see BehaviorSpace to run the same experiments reported in Miller-Atkins and Premo (2018).

Table 1: Parameter values used to initialize the simulations reported in Miller-Atkins and Premo (2018).

**Experimental Parameter**.............**Values**
_N_..............................................25
_initPopulation_..............................Heterogeneous
_extinctionProb_.............................0.01
_errorProb_...................................0.0001, .001, .01
_copyErrorModel_..........................bidirectSingleStepwise, finiteVariants, infiniteVariants
_cultTrans_...................................unbiased, vertical, conformist
_intergroupCTRate_.......................0, 0.05
_intergroupCTExtent_.....................local, global
_d_..............................................1, 1000, 10,000
_seed_.........................................1-20

### Data Collection
The relative frequency of the most prevalent cultural variant was collected for the assemblage in each patch in order to calculate Local Moran’s _Ii_ with the “spdep” package in R (Bivand and Piras 2015, Bivand et al. 2013). These data were collected at 10,001 (_d_=1), 10,010 (_d_=10), 10,100 (_d_=100), 11,000 (_d_=1000), and 20,000 (_d_=10,000) ticks.

## Submodels
### Intergroup Cultural Transmission ("intergroup-cultural-transmission"):
At the start of each time step, a proportion (intergroupCTRate/2) of individuals from the experienced generation are asked to pair with a member of a different group and then the pair swaps cultural variants across group boundaries. When intergroupCTExtent=local, the group from which the partner is chosen must be in the Moore neighborhood of ego (excluding ego's group).  When intergroupCTExtent=global, the group from which the partner is chosen can be any group other than ego's. Note that intergroup cultural transmission is horizontal and it is not susceptible to copy error in this model. 

### Local Extinction (“local-extinction”):
After intergrooup cultural transmission, each cell draws a random number from a uniform distribution between 0 and 1. If the number is less than extinctionprob all agents located on that cell die.

### Recolonization (“recolonize”):
The recoloniztion of empty cells occurs only after all groups have been exposed to local extinction. Each empty cell randomly selects one of its Moore neighbors (the 8 adjacent cells) that contains at least 2 members. The chosen patch sends half (rounded up) of its members (chosen randomly) to the empty cell. These recolonizers serve as the “experienced” generation of the vacant cell to which they move. The same group may be involved in multiple fission events during the course of a single time step.

### Intragroup Cultural Transmission (“intragroup-cultural-transmission”):
Cultural transmission from the experienced generation to the naive generation occurs via one of three mechanisms: conformist, unbiased, or vertical cultural transmission. In each case, naïve individuals learn from members of the experienced generation within their groups. Under conformist learning, each naive agent learns the modal variant displayed by the experienced generation within its group. If there are multiple modal variants, then each naive agent randomly selects one of the modal variants. Under unbiased cultural transmission, each naive agent randomly selects a teacher (with replacement) from the experienced members of its group. Unbiased cultural transmission allows for multiple naive agents to select the same teacher. Vertical transmission can be viewed as single parent-to-child transmission. Under vertical transmission, every member of the “experienced” generation in a group teaches an equal number of students whenever _N_ is a multiple of the size of the group’s experienced generation. For example, if there are 5 experienced individuals in a group, then each one will teach 5 naive individuals. However, if _N_ is not a multiple of the size of the group’s experienced generation, then some experienced individuals (chosen randomly) will teach one more student than the other experienced individuals.  For example, if there are 8 experienced individuals in a group, then 7 of them will teach 3 naive individuals and 1 of them (chosen randomly) will teach 4 naive individuals.

### Cultural Variant Deposition (“create-total-assemblage” and “create-patch-assemblage”):
There are two global lists in the model. The total diversity list includes every unique cultural variant deposited in the archaeological landscape though time. The total frequency list records the frequency (at the same position) of each unique cultural variant in the archaeological landscape.  Near the end of each time step, each individual compares its cultural variant to the total diversity list. If its integer is not already represented on the total diversity list, the agent adds its integer to the end of the total diversity list and adds a 1 to the end of the total frequency list, ensuring that information regarding that variant holds the same position in both lists. If the individual’s variant is already represented on the total diversity list, its previous frequency on the total frequency list is simply increased by 1 (say, from 22 to 23), but there is nothing new to add to the total diversity list.

Each patch contains two patch-specific lists similar to the global lists. The patch diversity list includes an entry for every unique cultural variant deposited in the patch through time. The patch frequency list records (at the same position) the number of times that each of the unique cultural variants in the patch occurs in the patch’s assemblage.  As in the global case, each individual in the patch first checks whether its cultural variant is present in the patch diversity list. If it is not present, the individual adds the integer value of its cultural variant to the end of the patch’s diversity list and inserts a "1" to the end of the patch frequency list using "lput". If the variant is present on the diversity list, then the individual increments by 1 the value on the frequency list that holds the same position as the cultural variant on the diversity list, but there is nothing new to add to the patch's diversity list.

### Calculate Relative Frequency of Most Prevalent Variant ("calculate-relative-freq")
This submodel is a patches method. It calculates the relative frequency of the "most prevalent variant" in each patch's assemblage.  If the patch's assemblage does not contain at least one instance of the most prevalent variant (i.e., most prevalent at the scale of the entire archaeological landscape over duration _d_), then relativeFreqMostPrevalentVariant is set to 0.  If the patch's assemblage does have at least one instance of the most prevalent variant, then relativeFreqMostPrevalentVariant is set equal to the frequency of the most prevalent variant in that patch's assemblage divided by the number of artifacts in the patch's assemblage.  Note that the denominator increases as a function of _d_.

## Important Model Assumptions/Caveats
The model was developed to investigate the effects of local group extinction and time-averaging on the scale of spatial association in the relative frequency of the most prevalent cultural variant in an archaeological landscape. The cultural variants in our model are selectively equivalent; variants do not differentially affect an agent’s ability to reproduce. This was a pragmatic decision. Archaeologists tend to address culture in the archaeological record by focusing on “stylistic” traits, traits that are assumed to have provided no fitness benefit to those who displayed them. The model could be modified to investigate traits that affect the fitness of those who display them. We chose not to do that here to better isolate the effects of local extinction and time-averaging.

It is also important to note that our model considers just one kind of recolonization—-namely, local recolonization. There are multiple ways to model recolonization, most of which would likely affect our results. For example, if colonizers were randomly drawn from the entire population, regardless of distance to the empty cell, rather than from just one neighboring cell, it is unlikely that new group would closely resemble its neighbors culturally. That is to say, without local recolonization, one would not expect clusters of culturally similar groups to emerge. Under such conditions, it may be impossible for the assemblages of spatially proximate cells to accumulate similar frequencies of the most prevalent cultural variant. In that case, one should expect spatial lag to have no effect on mean _Ii_ values, holding extinctionProb and _d_ constant.

## References Cited
Anselin, L. 1995. Local indicators of spatial association — LISA. _Geogr. Anal._ 27:93–115.

Bivand, R. S., Hauke, J., and Kossowski, T. 2013. Computing the Jacobian in Gaussian spatial autoregressive models: An illustrated comparison of available methods. _Geogr. Anal._ 45(2):150-179.

Bivand, R. S., Piras, G. 2015. Comparing Implementations of Estimation Methods for Spatial Econometrics. _J. of Stat. Software_ 63(18):1-36.

Ebert, J. 1992. _Distributional Archaeology._ University of New Mexico Press, Albuquerque.

Grimm, Volker, et al. 2010. The ODD protocol: a review and first update. _Ecol. Modeling_ 221:2760-2768.

Miller-Atkins, Galen A., Premo. L. S. 2018. Time-averaging and the spatial scale of regional cultural differentiation in archaeological assemblages. _Sci. Tech. Arch. Res._



# Contact Information

This model was programmed by Luke Premo and Galen Miller-Atkins.  Please feel free to share any comments, suggestions, corrections, or critiques with Luke Premo, who can be reached at this address:

Department of Anthropology
Washington State University
Pullman, WA 99164-4910

luke dot premo at wsu dot edu
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="exp2_figs5-7" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="20002"/>
    <enumeratedValueSet variable="N">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extinctionProb">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorProb">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectMoransData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copyErrorModel">
      <value value="&quot;bidirectSingleStepwise&quot;"/>
      <value value="&quot;finiteVariants&quot;"/>
      <value value="&quot;infiniteVariants&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTExtent">
      <value value="&quot;local&quot;"/>
      <value value="&quot;global&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTRate">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cultTrans">
      <value value="&quot;vertical&quot;"/>
      <value value="&quot;unbiased&quot;"/>
      <value value="&quot;conformist&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="20"/>
  </experiment>
  <experiment name="exp1_fig2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="20002"/>
    <enumeratedValueSet variable="N">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extinctionProb">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorProb">
      <value value="1.0E-4"/>
      <value value="0.001"/>
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectMoransData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copyErrorModel">
      <value value="&quot;bidirectSingleStepwise&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTExtent">
      <value value="&quot;global&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cultTrans">
      <value value="&quot;vertical&quot;"/>
      <value value="&quot;unbiased&quot;"/>
      <value value="&quot;conformist&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="20"/>
  </experiment>
  <experiment name="exp1_fig4" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="20002"/>
    <enumeratedValueSet variable="N">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extinctionProb">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorProb">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectMoransData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copyErrorModel">
      <value value="&quot;infiniteVariants&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTExtent">
      <value value="&quot;global&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cultTrans">
      <value value="&quot;vertical&quot;"/>
      <value value="&quot;unbiased&quot;"/>
      <value value="&quot;conformist&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="20"/>
  </experiment>
  <experiment name="exp1_fig3" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="20002"/>
    <enumeratedValueSet variable="N">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="extinctionProb">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="errorProb">
      <value value="1.0E-4"/>
      <value value="0.001"/>
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="collectMoransData">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initPopulation">
      <value value="&quot;heterogeneous&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="copyErrorModel">
      <value value="&quot;finiteVariants&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTExtent">
      <value value="&quot;global&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="intergroupCTRate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cultTrans">
      <value value="&quot;vertical&quot;"/>
      <value value="&quot;unbiased&quot;"/>
      <value value="&quot;conformist&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="20"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
